@@ -1,32 +1,38 @@
 #' ALE profile
 #'
-#' Internal function used by \code{light_profile} to calculate ALE profiles.
+#' Internal function used by [light_profile()] to calculate ALE profiles.
 #'
-#' @importFrom dplyr as_tibble left_join bind_rows group_by summarize across cur_data
-#' @importFrom tidyselect all_of
-#' @importFrom stats setNames
-#' @importFrom withr with_options
-#' @param x An object of class \code{flashlight}.
+#' @noRd
+#' @param x An object of class "flashlight".
 #' @param v The variable to be profiled.
-#' @param breaks Cut breaks for a numeric \code{v}. Only used if no \code{evaluate_at} is specified.
-#' @param n_bins Maxmium number of unique values to evaluate for numeric \code{v}. Only used if no \code{evaluate_at} is specified.
-#' @param cut_type For the default "equal", bins of equal width are created for \code{v} by \code{pretty}. Choose "quantile" to create quantile bins.
+#' @param breaks Cut breaks for a numeric `v`. Only used if no `evaluate_at` is specified.
+#' @param n_bins Maxmium number of unique values to evaluate for numeric `v`.
+#'   Only used if no `evaluate_at` is specified.
+#' @param cut_type For the default "equal", bins of equal width are created for `v`
+#'   by [pretty()]. Choose "quantile" to create quantile bins.
 #' @param counts Should counts be added?
-#' @param counts_weighted If \code{counts} is TRUE: Should counts be weighted by the case weights? If TRUE, the sum of \code{w} is returned by group.
+#' @param counts_weighted If `counts = TRUE`: Should counts be weighted by the
+#'   case weights? If `TRUE`, the sum of `w` is returned by group.
 #' @param pred Optional vector with predictions.
-#' @param evaluate_at Vector with values of \code{v} used to evaluate the profile. Only relevant for type = "partial dependence".
+#' @param evaluate_at Vector with values of `v` used to evaluate the profile.
+#'   Only relevant for type = "partial dependence".
 #' @param indices A vector of row numbers to consider.
 #' @param n_max Maximum number of ICE profiles to calculate within interval (not within data).
-#' @param seed Integer random seed passed to \code{light_ice}.
-#' @param two_sided Standard ALE profiles are calculated via left derivatives. Set to TRUE if two-sided derivatives should be calculated. Only works for continuous \code{v}. More specifically: Usually, local effects at value x are calculated using points between x-e and x. Set \code{ale_two_sided = TRUE} to use points between x-e/2 and x+e/2.
-#' @param calibrate Should values be calibrated based on average preditions? Default is TRUE.
+#' @param seed Integer random seed passed to [light_ice()].
+#' @param two_sided Standard ALE profiles are calculated via left derivatives.
+#'   Set to `TRUE` if two-sided derivatives should be calculated.
+#'   Only works for continuous `v`. More specifically: Usually, local effects at
+#'   value x are calculated using points in \eqn{[x-e, x]}. Set `ale_two_sided = TRUE`
+#'   to use points in \eqn{[x-e/2, x+e/2]} instead.
+#' @param calibrate Should values be calibrated based on average preditions?
+#'   Default is `TRUE`.
 #' @param ... Other arguments passed to this function (currently unused).
-#' @return A tibble containing results.
-ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
+#' @returns A tibble containing results.
+ale_profile <- function(x, v, breaks = NULL, n_bins = 11L,
                         cut_type = c("equal", "quantile"),
                         counts = TRUE, counts_weighted = FALSE,
                         pred = NULL, evaluate_at = NULL,
-                        indices = NULL, n_max = 1000, seed = NULL,
+                        indices = NULL, n_max = 1000L, seed = NULL,
                         two_sided = FALSE, calibrate = TRUE, ...) {
   cut_type <- match.arg(cut_type)
 
@@ -59,8 +65,7 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
     if (!is.null(breaks)) {
       evaluate_at <- midpoints(breaks)
     } else {
-      cuts <- auto_cut(data[[v]], breaks = breaks,
-                       n_bins = n_bins, cut_type = cut_type)
+      cuts <- auto_cut(data[[v]], breaks = breaks, n_bins = n_bins, cut_type = cut_type)
       breaks <- cuts$breaks
       evaluate_at <- cuts$bin_means
     }
@@ -68,7 +73,7 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
   if (two_sided) {
     if (!is.null(breaks)) {
       evaluate_at_orig <- evaluate_at
-      evaluate_at <- breaks[-1]
+      evaluate_at <- breaks[-1L]
     } else {
       two_sided <- FALSE
     }
@@ -76,8 +81,8 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
 
   # Helper function used to calculate differences for any pair of x values
   ale_core <- function(from_to) {
-    from <- from_to[1]
-    to <- from_to[2]
+    from <- from_to[1L]
+    to <- from_to[2L]
     if (is_num) {
       .s <- data[[v]] >= from & data[[v]] <= to
     } else {
@@ -87,11 +92,10 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
     if (nrow(dat_i) == 0L) {
       return(NULL)
     }
-    ice <- light_ice(x, v = v, data = dat_i, evaluate_at = from_to,
-                     n_max = n_max)$data
+    ice <- light_ice(x, v = v, data = dat_i, evaluate_at = from_to, n_max = n_max)$data
     if (is_num) {
-      ice[[value_name]] <- if (identical(to, from)) 0 else
-        ice[[value_name]] / (to - from)
+      ice[[value_name]] <-
+        if (identical(to, from)) 0 else ice[[value_name]] / (to - from)
     }
 
     # Safe reshaping
@@ -102,8 +106,12 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
 
     # Aggregation and output
     out <- grouped_stats(
-      dat_to, x = value_name, w = x$w, by = x$by,
-      counts_weighted = counts_weighted, na.rm = TRUE
+      dat_to,
+      x = value_name,
+      w = x$w,
+      by = x$by,
+      counts_weighted = counts_weighted,
+      na.rm = TRUE
     )
     out[[v]] <- to
     out
@@ -111,12 +119,11 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
 
   # Call ale_core once per interval and combine results
   eval_pair <- data.frame(
-    from = evaluate_at[c(1L, 1:(length(evaluate_at) - 1L))],
-    to = evaluate_at
+    from = evaluate_at[c(1L, 1:(length(evaluate_at) - 1L))], to = evaluate_at
   )
   withr::with_options(
     list(flashlight.id_name = id_name),
-    ale <- bind_rows(apply(eval_pair, 1, ale_core))
+    ale <- dplyr::bind_rows(apply(eval_pair, 1L, ale_core))
   )
 
   # Remove missing values before accumulation
@@ -131,9 +138,7 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
     )
     X
   }
-  ale <- if (is.null(x$by)) wcumsum(ale) else
-    summarize(group_by(ale, across(all_of(x$by))),
-              wcumsum(cur_data()), .groups = "drop")
+  ale <- Reframe(ale, FUN = wcumsum, .by = x$by)
 
   if (is.factor(data[[v]])) {
     ale[[v]] <- factor(ale[[v]], levels = levels(data[[v]]))
@@ -141,28 +146,32 @@ ale_profile <- function(x, v, breaks = NULL, n_bins = 11,
 
   # Calibrate effects
   if (calibrate) {
-    preds <- if (is.null(pred)) predict(x) else pred
+    preds <- if (is.null(pred)) stats::predict(x) else pred
     if (is.null(x$by)) {
-      pred_mean <- weighted_mean(preds, if (!is.null(x$w)) data[[x$w]],
-                                 na.rm = TRUE)
-      ale_mean <- weighted_mean(ale[[value_name]], w = ale[[counts_name]],
-                                na.rm = TRUE)
+      pred_mean <- MetricsWeighted::weighted_mean(
+        preds, if (!is.null(x$w)) data[[x$w]], na.rm = TRUE
+      )
+      ale_mean <- MetricsWeighted::weighted_mean(
+        ale[[value_name]], w = ale[[counts_name]], na.rm = TRUE
+      )
       ale[[value_name]] <- ale[[value_name]] - ale_mean + pred_mean
-      ale <- as_tibble(ale)
+      ale <- tibble::as_tibble(ale)
     } else {
       stopifnot(!(c("cal_xx", "shift_xx") %in% colnames(data)))
       dat_pred <- grouped_stats(
-        cbind(data, cal_xx = preds), x = "cal_xx", w = x$w,
-        by = x$by, counts = FALSE, na.rm = TRUE
+        cbind(data, cal_xx = preds),
+        x = "cal_xx",
+        w = x$w,
+        by = x$by,
+        counts = FALSE,
+        na.rm = TRUE
       )
       dat_ale <- grouped_stats(
-        ale, x = value_name, w = counts_name,
-        by = x$by, counts = FALSE, na.rm = TRUE
+        ale, x = value_name, w = counts_name, by = x$by, counts = FALSE, na.rm = TRUE
       )
-      dat_shift <- left_join(dat_ale, dat_pred, by = x$by)
-      dat_shift[["shift_xx"]] <- dat_shift[["cal_xx"]] -
-        dat_shift[[value_name]]
-      ale <- left_join(
+      dat_shift <- dplyr::left_join(dat_ale, dat_pred, by = x$by)
+      dat_shift[["shift_xx"]] <- dat_shift[["cal_xx"]] - dat_shift[[value_name]]
+      ale <- dplyr::left_join(
         ale,
         dat_shift[, c(x$by, "shift_xx"), drop = FALSE],
         by = x$by
