@@ -2,15 +2,12 @@
 #'
 #' Calculates weighted counts grouped by optional columns.
 #'
-#' @importFrom dplyr group_by summarize across cur_data
-#' @importFrom tidyselect all_of
-#' @importFrom stats setNames
-#' @param data A \code{data.frame}.
-#' @param by An optional vector of column names in \code{data} used to group the results.
-#' @param w Optional name of the column in \code{data} with case weights.
+#' @param data A `data.frame`.
+#' @param by An optional vector of column names in `data` used to group the results.
+#' @param w Optional name of the column in `data` with case weights.
 #' @param value_name Name of the resulting column with counts.
-#' @param ... Arguments passed to \code{sum} (only if weights are provided).
-#' @return A \code{data.frame} with columns \code{by} and \code{value_name}.
+#' @param ... Arguments passed to [sum()] (only if weights are provided).
+#' @returns A `data.frame` with columns `by` and `value_name`.
 #' @export
 #' @examples
 #' grouped_counts(iris)
@@ -28,13 +25,9 @@ grouped_counts <- function(data, by = NULL, w = NULL, value_name = "n", ...) {
   # Function that does the ungrouped calculation
   core_fun <- function(X) {
     val <- if (!is.null(w)) sum(X[[w]], ...) else nrow(X)
-    setNames(data.frame(val), value_name)
+    stats::setNames(data.frame(val), value_name)
   }
 
   # Apply core_fun
-  if (!length(by)) {
-    return(core_fun(data))
-  }
-  summarize(group_by(data, across(all_of(by))),
-    core_fun(cur_data()), .groups = "drop")
+  Reframe(data, FUN = core_fun, .by = by, as_tib = FALSE)
 }
