@@ -1,13 +1,12 @@
 #' Predictions for multiflashlight
 #'
-#' Predict method for an object of class \code{multiflashlight}. Pass additional elements to update the flashlight, typically \code{data}.
+#' Predict method for an object of class "multiflashlight".
+#' Pass additional elements to update the flashlight, typically `data`.
 #'
-#' @importFrom stats predict
-#' @param object An object of class \code{multiflashlight}.
+#' @param object An object of class "multiflashlight".
 #' @param ... Arguments used to update the multiflashlight.
-#' @return A named list of prediction vectors.
+#' @returns A named list of prediction vectors.
 #' @export
-#' @method predict multiflashlight
 #' @examples
 #' fit_part <- lm(Sepal.Length ~ Petal.Length, data = iris)
 #' fit_full <- lm(Sepal.Length ~ ., data = iris)
@@ -16,5 +15,5 @@
 #' mods <- multiflashlight(list(mod_full, mod_part), data = iris, y = "Sepal.Length")
 #' predict(mods, data = iris[1:5, ])
 predict.multiflashlight <- function(object, ...) {
-  lapply(object, predict, ...)
+  lapply(object, stats::predict, ...)
 }
