@@ -1,12 +1,13 @@
 #' Residuals for multiflashlight
 #'
-#' Residuals method for an object of class \code{multiflashlight}. Pass additional elements to update the multiflashlight before calculation of residuals.
+#' Residuals method for an object of class "multiflashlight".
+#' Pass additional elements to update the multiflashlight before calculation of
+#' residuals.
 #'
-#' @importFrom stats residuals
-#' @method residuals multiflashlight
-#' @param object An object of class \code{multiflashlight}.
-#' @param ... Arguments used to update the multiflashlight before calculating the residuals.
-#' @return A named list with residuals per flashlight.
+#' @param object An object of class "multiflashlight".
+#' @param ... Arguments used to update the multiflashlight before
+#'   calculating the residuals.
+#' @returns A named list with residuals per flashlight.
 #' @export
 #' @examples
 #' fit_part <- lm(Sepal.Length ~ Petal.Length, data = iris)
@@ -16,5 +17,5 @@
 #' mods <- multiflashlight(list(mod_full, mod_part), data = iris, y = "Sepal.Length")
 #' residuals(mods, data = head(iris))
 residuals.multiflashlight <- function(object, ...) {
-  lapply(object, residuals, ...)
+  lapply(object, stats::residuals, ...)
 }
